@@ -17,12 +17,12 @@ mod unix;
 #[cfg(unix)]
 pub use self::unix::*;
 
+#[cfg(target_os = "wasi")]
+mod wasi;
+#[cfg(target_os = "wasi")]
+pub use self::wasi::*;
+
 #[cfg(windows)]
 mod windows;
 #[cfg(windows)]
 pub use self::windows::*;
-
-#[cfg(target_os = "redox")]
-mod redox;
-#[cfg(target_os = "redox")]
-pub use self::redox::*;
